<?php
$page_title = "iWallet Card Application";
include_once('template/base_head.php');
?>
			<!-- サイドバー -->
			<aside id="colLeft">
				<h1><a href="/ja/menu"><img src="../img/logo.png" alt="iWallet"></a></h1>
<?php include_once('template/base_sidebar.php'); ?>
			</aside>
			<!-- /サイドバー -->
			<!-- メインカラム -->
			<div id="colMain">
				<div class="mainIn">
<?php include_once('template/base_nav.php'); ?>
					<article>
						<div class="article-heading">
							<h2><?php echo $page_title; ?></h2>
						</div>

						<p class="mb20 pleft40">Current Process</p>
						<div class="mb20 pleft40"><?php $this -> echoMessage(); ?></div>
						<form id="acForm" action="" method="post" class="pleft40 pb40">

							<table class="mb20 table col bdr withdrawT default odd calign w70p fontM ma90sp">
								<tr>
									<th class="w40p">Card 1</th>
									<td class="w60p l"><?php $this -> dispCardProgress(NO_COUNT); ?></td>
								</tr>
								<tr>
									<th class="w40p">Card 2</th>
									<td class="w60p l"><?php $this -> dispCardProgress(VAL_INT_1); ?></td>
								</tr>
							</table>

							<p class="mb20">
								<?php $this -> dispCardLimitRecharge(); ?> Cards with <?php $this -> dispCardLimit(); ?> are also open for application.<br/>
								<?php $this -> dispCardLimitWord(); ?><br/><br/>

								One person could have up to two active iWallet cards at the same time.<br/>
								You will be requested to pay the card fee inculding the delivery charge thru a "Money Request" send by iWallet. <br/>
								<br/><br/>

								Please fill in the information requested below accordingly.<br/>
							</p>
							<table class="table col bdr default odd calign withdrawT w70p fontM mb20 ma90sp">
								<tr>
									<th class="w40p">Please choose the card numbers you'd like to apply. </th>
									<td class="w60p l"><select id="index" name="index"><?php $this -> echoList(); ?></select>  piece(s)</td>
								</tr>
								<tr>
									<th class="w40p">Delivery Address</th>
									<td class="w60p l"><?php $this -> dispHTMLSipFlg(); ?><br/>If you already hold the cards, please choose "Registered Address".</td>
								</tr>

								<tr>
									<th class="w40p">Destination Country</th>
									<td id="td0Country" class="w70p l"><?php $this -> echoUserCountry(); ?></td>
									<td id="td1Country" style="display:none;" class="w60p l">
										<select id="country" name="country" class="w90p">
											<?php $this -> dispHTMLCountry(); ?>
										</select>
									</td>
								</tr>
								<tr>
									<th class="w40p">Destination State</th>
									<td id="td0State" class="w70p l"><?php $this -> echoState(); ?></td>
									<td id="td1State" style="display:none;" class="w60p l"><input class="w50p" type="text" id="state" name="state" value="<?php $this -> echoState(VAL_INT_1); ?>" /></td>
								</tr>
								<tr>
									<th class="w40p">Destination City</th>
									<td id="td0State" class="w70p l"><?php $this -> echoCity(); ?></td>
									<td id="td1State" style="display:none;" class="w60p l"><input class="w50p" type="text" id="city" name="city" value="<?php $this -> echoCity(VAL_INT_1); ?>" /></td>
								</tr>
								<tr>
									<th class="w40p">Destination Address</th>
									<td id="td0Address" class="w70p l"><?php $this -> echoAddress(); ?></td>
									<td id="td1Address" style="display:none;" class="w60p l"><input class="w50p" type="text" id="address" name="address" value="<?php $this -> echoAddress(VAL_INT_1); ?>" /></td>
								</tr>
								<tr>
									<th class="w40p">ZIP Code</th>
									<td id="td0ZipCode" class="w70p l"><?php $this -> echoZipCode(); ?></td>
									<td id="td1ZipCode" style="display:none;" class="w60p l"><input class="w50p" type="text" id="zip_code" name="zip_code" value="<?php $this -> echoZipCode(VAL_INT_1); ?>" /></td>
								</tr>
								<tr>
									<th class="w40p">Contact Number</th>
									<td id="td0Tel" class="w70p l"><?php $this -> echoTel(); ?></td>
									<td id="td1Tel" style="display:none;" class="w60p l"><input class="w50p" type="text" id="tel" name="tel" value="<?php $this -> echoTel(VAL_INT_1); ?>" /></td>
								</tr>
							</table>
							<p class="mb40 mt40 w70pButton">
								<input type="button" id="btnConfirm" value="Continue" class="btn bg-grad px150">
							</p>
							<?php //$this -> echoList(); ?>

							<input type="hidden" id="type" name="type" value="" />
							<input type="hidden" value="list" name="action" />
							<input type="hidden" value="" id="r_id" name="r_id" />
						</form>


					</article>
				</div>
			</div>
			<!-- /メインカラム -->
		</div>
<?php include_once('template/base_foot.php'); ?>
	</div>
	<script src="../js/card_apply.js"></script>
</body>
</html>